@@ -16,7 +16,8 @@ class GithubService:
 
     def __init__(self, github_config: cs.GhConnectionSettings) -> None:
         """Constructor."""
-        self.connection = self._get_connection(github_config)
+        self.config = github_config
+        self.connection = self._get_connection(self.config)
         self.user = self._test_connection(self.connection)
         self.repos = self.connection.repositories()
 
@@ -43,9 +44,13 @@ class GithubService:
         try:
             return connection.me()
         except github3.exceptions.AuthenticationFailed:
-            raise AttributeError()
+            raise AttributeError("Invalid token.")
         except github3.exceptions.ConnectionError:
             raise ConnectionError()
+        except github3.exceptions.IncompleteResponse:
+            raise AttributeError(
+                "Invalid response. Your token might not be properly scoped."
+            )
 
     def _get_repo(self, repo_name: str) -> github3.repos.ShortRepository:
         for repo in self.repos:
@@ -53,6 +58,10 @@ class GithubService:
                 return repo
         raise NameError(f"Repository {repo_name} not found.")
 
+    def get_config(self) -> cs.GhConnectionSettings:
+        """Get service config."""
+        return self.config
+
     def get_repo_names(self) -> List[str]:
         """Get list of repository names."""
         return [repo.full_name for repo in self.repos]
